# Authors

To see the list of btclib authors for copyright purposes, see the revision
history in source control:
<https://github.com/btclib-org/btclib/graphs/contributors>

This does not necessarily list everyone who has contributed code, since in
some cases, their employer may be the copyright holder
